

#ifndef __MINUS_H__
#define __MINUS_H__

// Librairies

#include <timers.h>
#include <pwm.h>
#include <usart.h>
#include <adc.h>
#include "rs232.h"



// Constantes 

#define 	T_TIMER3 	15536			   	// 200ms avant dbordement du Timer
											// Priode du quartz : 1/20e6 = 50ns
											// Priode  l'entre du prescaler : 50ns.4=200ns
											// Priode  la sortie du prescaler : 200ns.1=200ns
											// Nombre de priodes avant dbordement du timer : 5000 incrments
											// Priode entre deux interruptions : 5000*200ns = 1ms
											// Priode de 1ms -> 1KHz

	


// Prototype des fonctions

void ConfigProcess(void);
void Moteurgauche (int Vit);
void Moteurdroit (int Vit);
void TableauCapteur(char capt[]);
unsigned char PrioriteIR1(void);
unsigned char PrioriteIR2(void);
unsigned char PrioriteIR3(void);
unsigned char DevantIR(void);

//------------------------------------------------------------------------------------

// Configure le micro

void ConfigProcess(void)
{

	// Configure les E/S 1=entre 0=sortie

	TRISA = 0b11111111;		// xxxxxx | xxxxxx |  AN4   |CHA_G  | AN3    | AN2    | AN1    | AN0
	TRISB = 0b00110111;		// DIR_G  | DIR_D  | sens_G | sens_D| RB3    | RB2    | RB1    | Jack
	TRISC = 0b10000001;		//  RX    | TX     |  RC5   | SDA   | SCL    | pwm_g  | pwm_d   |ChA_D  
	TRISD = 0b11111111;		// Data7  | Data6  | Data5	| Data4 | Data3  | Data2  | Data1  | Data0
	TRISE = 0b001;			//  Ad1|  | Ad0    | VCC Bat

	// Configure les timers 1 et 2 en compteurs pour les codeurs

	OpenTimer0 (TIMER_INT_OFF & T0_16BIT & T0_SOURCE_EXT & T0_EDGE_RISE & T0_PS_1_1); //compteur compte le nombre d'impulsion du codeur gauche
	OpenTimer1 (TIMER_INT_OFF & T1_16BIT_RW & T1_SOURCE_EXT & T1_PS_1_1 & T1_OSC1EN_OFF & T1_SYNC_EXT_OFF); //compteur compte le nombre d'impulsion du codeur droit


	// Configure le Timer 2 pour le PWM

	OpenTimer2 (TIMER_INT_OFF &	T2_PS_1_1 &	T2_POST_1_1); 	//pour le PWM
	OpenPWM1(0xFF);											//frquence du PWM : 19531 Hz 
	OpenPWM2(0xFF);
	SetDCPWM1(0x00);
	SetDCPWM2(0x00);

	// Configure le timer 3 pour la base de temps (10ms)

	OpenTimer3(	TIMER_INT_ON &			// Autorise les interruption sur le timer 3
				T3_16BIT_RW &			// Compteur 16 bits
				T3_SOURCE_INT &			// Source interne (Quartz Fosc/4)
				T3_PS_1_1 &				// Prescaler 1/1
				T3_SYNC_EXT_OFF);		// Pas de synchronisation externe

	WriteTimer3(T_TIMER3);				// Charge le compteur du timer 3 avec la valeur de T_Timer3
	PIR2bits.TMR3IF=0;					// Timer3 Interrupt Flag = 0 Baisse le flag du timer 3

	// Configure les convertisseur A/N
 	
	OpenADC(ADC_FOSC_2 & ADC_RIGHT_JUST & ADC_5ANA_0REF , ADC_CH1 & ADC_INT_OFF);//configure tous les ports en numrique

	// Configure la liaison srie	

	OpenUSART(USART_TX_INT_OFF & USART_RX_INT_OFF & USART_ASYNCH_MODE & USART_EIGHT_BIT & USART_SYNC_SLAVE & USART_CONT_RX & USART_BRGH_HIGH,10);

	// Autorise les interruptions
	
	INTCONbits.PEIE=1;					// Autorise les interruptions lies aux priphriques
	INTCONbits.GIE=1;					// Autorisation gnrale des interruptions non masques



}


//	Spcifie la vitesse du moteur gauche

void Moteurgauche (int Vit)
{
	if(Vit>=0)
	{
		SetDCPWM1(Vit);
		DIR_G=0;
	}
	else
	{
		SetDCPWM1(-Vit);
		DIR_G=1;
	}		
}



// Spcifie la vitesse du moteur droit

void Moteurdroit (int Vit)
{
	if(Vit>=0)
	{
		SetDCPWM2(Vit);
		DIR_D=0;
	}
	else
	{
		SetDCPWM2(-Vit);
		DIR_D=1;
	}				
}


//------------------------------------------------------------------------------------	
//capt:pointeur de tableau de caractre.
//fait:remplie le table capt en fonction des tats des capteurs.
void TableauCapteur(char capt[])
{


	Ad0=0;
	Ad1=0;
	capt[0]=!Data0;
	capt[1]=!Data1;
	capt[2]=!Data2;
	capt[3]=!Data3;
	capt[4]=!Data4;
	capt[5]=!Data5;
	capt[6]=!Data6;
	capt[7]=!Data7;
	


	Ad0=1;
	Ad1=0;
	capt[8]=!Data0;
	capt[9]=!Data1;
	capt[10]=!Data2;
	capt[11]=!Data3;
	capt[12]=!Data4;
	capt[13]=!Data5;
	capt[14]=!Data6;
	capt[15]=!Data7;


	Ad0=0;
	Ad1=1;
	capt[16]=!Data0;
	capt[17]=!Data1;
	capt[18]=!Data2;
	capt[19]=!Data3;
	capt[20]=!Data4;
	capt[21]=!Data5;
	capt[22]=!Data6;
	capt[23]=!Data7;

	Ad0=1;
	Ad1=1;
	capt[24]=!Data0;
	capt[25]=!Data1;
	capt[26]=!Data2;
	capt[27]=!Data3;
	capt[28]=!Data4;
	capt[29]=!Data5;
	capt[30]=!Data6;
	capt[31]=!Data7;

}




//------------------------------------------------------------------------------------	
unsigned char PrioriteIR1(void)
{

	SetChanADC (ADC_CH1);
	Delay10TCYx(5);
	ConvertADC();
	while (BusyADC());	
	if(ReadADC()<100)//SI robot dtct sur la droite
	{
		return 1;
	}
	else
	{
		return 0;
	}


}
//------------------------------------------------------------------------------------	
unsigned char PrioriteIR2(void)
{

	SetChanADC (ADC_CH2);
	Delay10TCYx(5);
	ConvertADC();
	while (BusyADC());	
	if(ReadADC()<100)//SI robot dtct sur la droite
	{
		return 1;
	}
	else
	{
		return 0;
	}
}

//------------------------------------------------------------------------------------	
unsigned char PrioriteIR3(void)
{

	SetChanADC (ADC_CH3);
	Delay10TCYx(5);
	ConvertADC();
	while (BusyADC());	
	if(ReadADC()<100)//SI robot dtct sur la droite
	{
		return 1;
	}
	else
	{
		return 0;
	}
}

//------------------------------------------------------------------------------------	
unsigned char DevantIR(void)
{

	SetChanADC (ADC_CH1);
	Delay10TCYx(5);
	ConvertADC();
//	while (BusyADC());	
	if(ReadADC()<600)//SI obstacle detect devant
	{
		return 1;
	}
	else
	{
		return 0;
	}
}


#endif
